Crate aas

Crate aas 

This crate defines data types according to the asset administration shell specifications

To support multiple specs and multiple versions of each, this crate it split in multiple modules for each part as well as version. Because each spec is versioned on their own, the modules are ordered specs/version instead of version/specs, i.e. aas::part1::v3.1.

Modules

part_1
Part1: Metamodel
utilities
Utility functions like validating text to specific formats and deserializers to specific needs, like text with defined constraints.